@@ -1,9 +1,3 @@
-from litchi.lang.base import get_source
-
-def brython(func):
-    code = get_source(func)
-    return code
-
 class Brython:
     def __init__(self, function):
         self.function = function
